Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(214)

Unified Diff: runtime/vm/raw_object.h

Issue 8761011: Renaming type classes as discussed: (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: '' Created 9 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: runtime/vm/raw_object.h
===================================================================
--- runtime/vm/raw_object.h (revision 1948)
+++ runtime/vm/raw_object.h (working copy)
@@ -17,8 +17,8 @@
#define CLASS_LIST_NO_OBJECT(V) \
V(Class) \
V(UnresolvedClass) \
- V(Type) \
- V(ParameterizedType) \
+ V(AbstractType) \
+ V(Type) \
V(TypeParameter) \
V(InstantiatedType) \
V(TypeArguments) \
@@ -37,7 +37,7 @@
V(Context) \
V(ContextScope) \
V(UnhandledException) \
- V(ApiError) \
+ V(ApiError) \
V(Instance) \
V(Number) \
V(Integer) \
@@ -222,12 +222,12 @@
RawString* name_;
RawArray* functions_;
RawArray* fields_;
- RawArray* interfaces_; // Array of Type.
+ RawArray* interfaces_; // Array of AbstractType.
regis 2011/12/01 04:24:07 Could be RawTypeArguments*.
RawScript* script_;
RawLibrary* library_;
RawArray* type_parameters_; // Array of String.
RawTypeArray* type_parameter_extends_; // DynamicType if no extends clause.
- RawType* super_type_;
+ RawAbstractType* super_type_;
regis 2011/12/01 04:24:07 Could be RawType*.
srdjan 2011/12/01 17:48:42 Done in next CL.
RawObject* factory_class_; // UnresolvedClass (until finalization) or Class.
RawFunction* signature_function_; // Associated function for signature class.
RawArray* functions_cache_; // See class FunctionsCache.
@@ -269,14 +269,14 @@
};
-class RawType : public RawObject {
- RAW_HEAP_OBJECT_IMPLEMENTATION(Type);
+class RawAbstractType : public RawObject {
+ RAW_HEAP_OBJECT_IMPLEMENTATION(AbstractType);
friend class ObjectStore;
};
-class RawParameterizedType : public RawType {
+class RawType : public RawAbstractType {
private:
enum TypeState {
kAllocated, // Initial state.
@@ -284,7 +284,7 @@
kFinalized, // Type ready for use.
};
- RAW_HEAP_OBJECT_IMPLEMENTATION(ParameterizedType);
+ RAW_HEAP_OBJECT_IMPLEMENTATION(Type);
RawObject** from() {
return reinterpret_cast<RawObject**>(&ptr()->type_class_);
@@ -296,7 +296,7 @@
};
-class RawTypeParameter : public RawType {
+class RawTypeParameter : public RawAbstractType {
private:
RAW_HEAP_OBJECT_IMPLEMENTATION(TypeParameter);
@@ -307,14 +307,14 @@
};
-class RawInstantiatedType : public RawType {
+class RawInstantiatedType : public RawAbstractType {
private:
RAW_HEAP_OBJECT_IMPLEMENTATION(InstantiatedType);
RawObject** from() {
return reinterpret_cast<RawObject**>(&ptr()->uninstantiated_type_);
}
- RawType* uninstantiated_type_;
+ RawAbstractType* uninstantiated_type_;
RawTypeArguments* instantiator_type_arguments_;
RawObject** to() {
return reinterpret_cast<RawObject**>(&ptr()->instantiator_type_arguments_);
@@ -337,7 +337,7 @@
RawSmi* length_;
// Variable length data follows here.
- RawType* types_[0];
+ RawAbstractType* types_[0];
RawObject** to(intptr_t length) {
return reinterpret_cast<RawObject**>(&ptr()->types_[length - 1]);
}
@@ -381,7 +381,7 @@
RawObject** from() { return reinterpret_cast<RawObject**>(&ptr()->name_); }
RawString* name_;
RawClass* owner_;
- RawType* result_type_;
+ RawAbstractType* result_type_;
RawArray* parameter_types_;
RawArray* parameter_names_;
RawCode* code_; // Compiled code for the function.
@@ -413,7 +413,7 @@
RawObject** from() { return reinterpret_cast<RawObject**>(&ptr()->name_); }
RawString* name_;
RawClass* owner_;
- RawType* type_;
+ RawAbstractType* type_;
RawInstance* value_; // Offset for instance and value for static fields.
RawObject** to() { return reinterpret_cast<RawObject**>(&ptr()->value_); }
@@ -599,7 +599,7 @@
RawSmi* token_index;
RawString* name;
RawBool* is_final;
- RawType* type;
+ RawAbstractType* type;
RawSmi* context_index;
RawSmi* context_level;
};
« runtime/vm/parser.h ('K') | « runtime/vm/parser.cc ('k') | runtime/vm/raw_object.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698